﻿Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition
Imports PdfSharp.Pdf

Public Class Form1

  Private Sub cmdPrint_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles cmdPrint.Click
    Me.buildSpatialIndex_Click(sender, e)
  End Sub

  Private Sub Form1_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
    Me.CreateASpatialIndexForAShapeFileLayer_Load(sender, e)
  End Sub

  Private Sub CreateASpatialIndexForAShapeFileLayer_Load(ByVal sender As Object, ByVal e As EventArgs)

    WinformsMap1.MapUnit = GeographyUnit.DecimalDegree
    WinformsMap1.CurrentExtent = New RectangleShape(-111.78749999999999, 92.0859375, 148.36875000000001, -93.5390625)
    WinformsMap1.BackgroundOverlay.BackgroundBrush = New GeoSolidBrush(GeoColor.GeographicColors.ShallowOcean)

    Dim worldImageLayer As New EcwRasterLayer("..\..\SampleData\Data\World.ecw")

    Dim worldLayer As New ShapeFileFeatureLayer("..\..\SampleData\Data\Countries02.shp")
    worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1
    worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.StartCap = DrawingLineCap.Round
    worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.EndCap = DrawingLineCap.Round
    worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

    Dim usStatesLayer As New ShapeFileFeatureLayer("..\..\SampleData\Data\USStates.shp")
    usStatesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.State2
    usStatesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.StartCap = DrawingLineCap.Round
    usStatesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

    Dim worldCapitalsLayer As New ShapeFileFeatureLayer("..\..\SampleData\Data\WorldCapitals.shp")
    worldCapitalsLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.Capital3
    worldCapitalsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

    Dim worldCapitalsLabelsLayer As New ShapeFileFeatureLayer("..\..\SampleData\Data\WorldCapitals.shp")
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Capital3("city_name")
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen = New GeoPen(GeoColor.StandardColors.White, 2)
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen.StartCap = DrawingLineCap.Round
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.HaloPen.EndCap = DrawingLineCap.Round
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle.SuppressPartialLabels = True
    worldCapitalsLabelsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

    Dim staticOverlay As New LayerOverlay()
    staticOverlay.Layers.Add("WorldImageLayer", worldImageLayer)
    staticOverlay.Layers.Add("WorldLayer", worldLayer)
    staticOverlay.Layers.Add("USStatesLayer", usStatesLayer)
    staticOverlay.Layers.Add("WorldCapitals", worldCapitalsLayer)
    staticOverlay.Layers.Add("WorldCapitalsLabels", worldCapitalsLabelsLayer)
    WinformsMap1.Overlays.Add(staticOverlay)

    WinformsMap1.Refresh()
  End Sub

  ' Here we setup the PDF page and then create our PDFGeoCanvas.
  ' We loop through all the layers to draw and then save & pop the 
  ' PDF
  Private Sub buildSpatialIndex_Click(ByVal sender As Object, ByVal e As EventArgs)
    Dim document As New PdfDocument()
    Dim page As PdfPage = document.AddPage()
    'If pageOrientationLandscape.Checked = True Then
    '  page.Orientation = PageOrientation.Landscape
    'End If

    Dim pdfGeoCanvas As New PdfGeoCanvas()

    ' This allows you to control the area in which you want the 
    ' map to draw in. Leaving this commented out uses the whole page 
    'pdfGeoCanvas.DrawingArea = new Rectangle(200, 50, 400, 400); 
    Dim labelsInLayers As New System.Collections.ObjectModel.Collection(Of SimpleCandidate)()
    For Each layer As Layer In DirectCast(WinformsMap1.Overlays(0), LayerOverlay).Layers
      pdfGeoCanvas.BeginDrawing(page, WinformsMap1.CurrentExtent, GeographyUnit.DecimalDegree)
      layer.Open()
      layer.Draw(pdfGeoCanvas, labelsInLayers)
      layer.Close()
      pdfGeoCanvas.EndDrawing()
    Next

    Dim filename As String = GetTemporaryFolder() & "\MapSuite PDF Map.pdf"
    Try
      document.Save(filename)
      OpenPdfFile(filename)
    Catch ex As Exception
      Dim message As String = "You have no permission to write file to disk." + ex.Message
      MessageBox.Show(message, "Not permitted", MessageBoxButtons.OK, MessageBoxIcon.Error, MessageBoxDefaultButton.Button1, MessageBoxOptions.DefaultDesktopOnly)
    End Try
  End Sub

  Friend Shared Function GetTemporaryFolder() As String
    Dim returnValue As String = String.Empty
    If String.IsNullOrEmpty(returnValue) Then
      returnValue = Environment.GetEnvironmentVariable("Temp")
    End If

    If String.IsNullOrEmpty(returnValue) Then
      returnValue = Environment.GetEnvironmentVariable("Tmp")
    End If

    If String.IsNullOrEmpty(returnValue) Then
      returnValue = "c:\MapSuiteTemp"
    Else
      returnValue = returnValue & "\" & "MapSuite"
    End If

    Return returnValue
  End Function

  Private Shared Sub OpenPdfFile(ByVal filename As String)
    Try
      Process.Start(filename)
    Catch ex As System.ComponentModel.Win32Exception
      If ex.Message = "No application is associated with the specified file for this operation" Then
        'string message = "You can't open Pdf file, the reason maybe you don't install Adobe Reader\r\n\r\n" + ex.ToString();
        'MessageBox.Show(message, "Open Pdf file failed", MessageBoxButtons.OK, MessageBoxIcon.Error, MessageBoxDefaultButton.Button1, (MessageBoxOptions)0);
        Dim psi As New ProcessStartInfo("C:\WINDOWS\system32\rundll32.exe")
        psi.Arguments = " C:\WINDOWS\system32\shell32.dll, OpenAs_RunDLL " + filename
        Process.Start(psi)
      End If
    End Try
  End Sub

End Class
